unit fMain;

interface

uses
  System.SysUtils,
  System.Types,
  System.UITypes,
  System.Classes,
  System.Variants,
  FMX.Types,
  FMX.Controls,
  FMX.Forms,
  FMX.Graphics,
  FMX.Dialogs,

  // TMS
  FMX.TMSFNCTypes,
  FMX.TMSFNCUtils,
  FMX.TMSFNCGraphics,
  FMX.TMSFNCGraphicsTypes,
  FMX.TMSFNCCustomControl,
  FMX.TMSFNCWebBrowser,
  FMX.TMSFNCMaps,
  FMX.TMSFNCGoogleMaps,
  FMX.Layouts;

Type
  TMSmapOVRec = record
    imgSrc: String;
    coNorth: Single;
    coSourth: Single;
    coEast: Single;
    coWest: Single;
  end;

type
  TFormMain = class(TForm)
    layMap: TLayout;
    procedure FormShow(Sender: TObject);
  private
    { Private declarations }
    FMap: TTMSFNCGoogleMaps;
    procedure FetchCoverageMap(Sender: TObject);
    procedure AddOverlay;
    procedure AddCoverageMapLayers(const ovRec: TMSmapOVRec);

  public
    { Public declarations }
  end;

var
  FormMain: TFormMain;

Const
  GOOGLE_MAP_API = '';

implementation

{$R *.fmx}

procedure TFormMain.AddCoverageMapLayers(const ovRec: TMSmapOVRec);
var
  ov: TTMSFNCGoogleMapsOverlayView;
begin

  ov      := FMap.AddOverlayView;
  ov.Mode := omBounds;
  ov.Text := '<img src="' + ovRec.imgSrc +
    '" style="position:absolute;width:100%;height:100%;opacity:0.45;z-index:10">';
  ov.Bounds.NorthEast.Latitude  := ovRec.coNorth;
  ov.Bounds.NorthEast.Longitude := ovRec.coEast;
  ov.Bounds.SouthWest.Latitude  := ovRec.coSourth;
  ov.Bounds.SouthWest.Longitude := ovRec.coWest;
  ov.Visible                    := True;
  ov.CoordinatePosition         := cpTopRight;
  // ov.Width              := 500;
  // ov.Height             := 500;
  ov.Padding         := 0;
  ov.BackgroundColor := gcNull;
  ov.BorderColor     := gcNull;
  ov.Clickable       := False;

end;

procedure TFormMain.AddOverlay;
begin
  var
    anImg_1: TMSmapOVRec;

    // anImg_1.imgSrc := 'https://tiles.sigfox.com/56dc9216ab1941bc89eec1fefb988f55/5/18/18.png';
  anImg_1.imgSrc   := 'https://nerospec.app/downloads/jojo/181.png';
  anImg_1.coNorth  := -21.943046;
  anImg_1.coSourth := -31.952162;
  anImg_1.coEast   := 33.75;
  anImg_1.coWest   := 22.5;

  var
    anImg_2: TMSmapOVRec;

  anImg_2.imgSrc   := 'https://nerospec.app/downloads/jojo/18_2.png';
  anImg_2.coNorth  := -21.943046;
  anImg_2.coSourth := -31.952162;
  anImg_2.coEast   := 22.5;
  anImg_2.coWest   := 11.25;

  var
    anImg_3: TMSmapOVRec;

  anImg_3.imgSrc   := 'https://nerospec.app/downloads/jojo/19_1.png';
  anImg_3.coNorth  := -31.952162;
  anImg_3.coSourth := -40.979898;
  anImg_3.coEast   := 33.75;
  anImg_3.coWest   := 22.5;

  var
    anImg_4: TMSmapOVRec;

  anImg_4.imgSrc   := 'https://nerospec.app/downloads/jojo/19_2.png';
  anImg_4.coNorth  := -31.952162;
  anImg_4.coSourth := -40.979898;
  anImg_4.coEast   := 22.5;
  anImg_4.coWest   := 11.25;

  FMap.BeginUpdate;
  FMap.OverlayViews.Clear;
  FMap.OverlayViews.BeginUpdate;
  AddCoverageMapLayers(anImg_1);
  AddCoverageMapLayers(anImg_2);
  AddCoverageMapLayers(anImg_3);
  AddCoverageMapLayers(anImg_4);
  FMap.OverlayViews.EndUpdate;
  FMap.EndUpdate;
end;

procedure TFormMain.FetchCoverageMap(Sender: TObject);
begin
  AddOverlay;
end;

procedure TFormMain.FormShow(Sender: TObject);
begin

  if Assigned(FMap) then
  begin
    FMap.Visible := True;
    // FMap.DeInitialize;
    FMap.Initialize;
    Exit;

  end;

  FMap := TTMSFNCGoogleMaps.Create(Self);
  FMap.DisableBackground;
  // FMap.Visible := False;

  FMap.OnMapInitialized := FetchCoverageMap;

  FMap.APIKey                   := GOOGLE_MAP_API;
  FMap.Options.DefaultLatitude  := -28.480238;
  FMap.Options.DefaultLongitude := 24.812671;
  FMap.Options.DefaultZoomLevel := 4;
  FMap.Options.Panning          := True;
  FMap.Options.Version          := 'beta';
  // FMap.Options.MapTypeID        := gmtSatellite;

  // remove unnecessary controls
  FMap.Options.ShowTraffic           := False;
  FMap.Options.ShowStreetViewControl := False;
  FMap.Options.ShowMapTypeControl    := False;
  FMap.Options.ShowBicycling         := False;
  FMap.Options.ShowStreetViewControl := False;
  FMap.Options.ShowScaleControl      := False;
  FMap.Options.ShowZoomControl       := True;

  // FMap.Options.MapStyle := MAPSTYLENIGHT;

{$IFDEF MSWINDOWS}
  FMap.Align         := TAlignLayout.Client;
  FMap.Margins.Top   := 10;
  FMap.Margins.Left  := 20;
  FMap.Margins.Right := 20;
  // layMap.AddObject(FMap);

  layMap.Visible := False;

  Self.AddObject(FMap);
{$ELSE}
  FMap.Position.X := layMap.Position.X * 1.2; // nsAppInfo.UIScale;
  FMap.Position.Y := layMap.Position.Y * 1.2; // nsAppInfo.UIScale;
  FMap.Width      := layMap.Width * 1.2; // nsAppInfo.UIScale;
  FMap.Height     := layMap.Height;
  Self.AddObject(FMap);
{$ENDIF}
  // FMap.DeInitialize;

  // FMap.Visible := True;
  // FMap.RecalcSize;
  FMap.Initialize;
end;

end.
